@@ -78,6 +78,21 @@ void dumptime( time_t *the_time, clock_t *the_jiffies)
     perror("times");
 }
 
+
+int record_tid_activated = 0;
+
+/* activate the recording of thread id */
+void fut_enable_tid_logging()
+{
+  record_tid_activated = 1;
+}
+
+/* disactivate the recording of thread id */
+void fut_disable_tid_logging()
+{
+  record_tid_activated = 0;
+}
+
 /*	called once to set up tracing.
 	includes mallocing the buffer to hold the trace.
 	returns number of bytes allocated if all ok, else a negative error code.
